/* Locale.c generated by valac 0.56.19, the Vala compiler
 * generated from Locale.vala, do not modify */

#include <glib-object.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_UTILS_TYPE_LOCALES (tuba_utils_locales_get_type ())
#define TUBA_UTILS_LOCALES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_UTILS_TYPE_LOCALES, TubaUtilsLocales))
#define TUBA_UTILS_LOCALES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_UTILS_TYPE_LOCALES, TubaUtilsLocalesClass))
#define TUBA_UTILS_IS_LOCALES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_UTILS_TYPE_LOCALES))
#define TUBA_UTILS_IS_LOCALES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_UTILS_TYPE_LOCALES))
#define TUBA_UTILS_LOCALES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_UTILS_TYPE_LOCALES, TubaUtilsLocalesClass))

typedef struct _TubaUtilsLocales TubaUtilsLocales;
typedef struct _TubaUtilsLocalesClass TubaUtilsLocalesClass;
typedef struct _TubaUtilsLocalesPrivate TubaUtilsLocalesPrivate;
enum  {
	TUBA_UTILS_LOCALES_0_PROPERTY,
	TUBA_UTILS_LOCALES_NUM_PROPERTIES
};
static GParamSpec* tuba_utils_locales_properties[TUBA_UTILS_LOCALES_NUM_PROPERTIES];

#define TUBA_UTILS_LOCALES_TYPE_LOCALE (tuba_utils_locales_locale_get_type ())
#define TUBA_UTILS_LOCALES_LOCALE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_UTILS_LOCALES_TYPE_LOCALE, TubaUtilsLocalesLocale))
#define TUBA_UTILS_LOCALES_LOCALE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_UTILS_LOCALES_TYPE_LOCALE, TubaUtilsLocalesLocaleClass))
#define TUBA_UTILS_LOCALES_IS_LOCALE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_UTILS_LOCALES_TYPE_LOCALE))
#define TUBA_UTILS_LOCALES_IS_LOCALE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_UTILS_LOCALES_TYPE_LOCALE))
#define TUBA_UTILS_LOCALES_LOCALE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_UTILS_LOCALES_TYPE_LOCALE, TubaUtilsLocalesLocaleClass))

typedef struct _TubaUtilsLocalesLocale TubaUtilsLocalesLocale;
typedef struct _TubaUtilsLocalesLocaleClass TubaUtilsLocalesLocaleClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _TubaUtilsLocalesLocalePrivate TubaUtilsLocalesLocalePrivate;
enum  {
	TUBA_UTILS_LOCALES_LOCALE_0_PROPERTY,
	TUBA_UTILS_LOCALES_LOCALE_LOCALE_PROPERTY,
	TUBA_UTILS_LOCALES_LOCALE_EN_NAME_PROPERTY,
	TUBA_UTILS_LOCALES_LOCALE_NAME_PROPERTY,
	TUBA_UTILS_LOCALES_LOCALE_NUM_PROPERTIES
};
static GParamSpec* tuba_utils_locales_locale_properties[TUBA_UTILS_LOCALES_LOCALE_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

struct _TubaUtilsLocales {
	GObject parent_instance;
	TubaUtilsLocalesPrivate * priv;
	GListStore* list_store;
};

struct _TubaUtilsLocalesClass {
	GObjectClass parent_class;
};

struct _TubaUtilsLocalesLocale {
	GObject parent_instance;
	TubaUtilsLocalesLocalePrivate * priv;
};

struct _TubaUtilsLocalesLocaleClass {
	GObjectClass parent_class;
};

struct _TubaUtilsLocalesLocalePrivate {
	gchar* _locale;
	gchar* _en_name;
	gchar* _name;
};

static gpointer tuba_utils_locales_parent_class = NULL;
static gint TubaUtilsLocalesLocale_private_offset;
static gpointer tuba_utils_locales_locale_parent_class = NULL;
VALA_EXTERN GEqualFunc tuba_utils_locales_locale_compare;
GEqualFunc tuba_utils_locales_locale_compare = NULL;

VALA_EXTERN GType tuba_utils_locales_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaUtilsLocales, g_object_unref)
VALA_EXTERN GType tuba_utils_locales_locale_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaUtilsLocalesLocale, g_object_unref)
VALA_EXTERN TubaUtilsLocales* tuba_utils_locales_new (void);
VALA_EXTERN TubaUtilsLocales* tuba_utils_locales_construct (GType object_type);
static gboolean _tuba_utils_locales_locale_compare_lambda50_ (const gchar* a,
                                                       const gchar* b);
VALA_EXTERN const gchar* tuba_utils_locales_locale_get_locale (TubaUtilsLocalesLocale* self);
static gboolean __tuba_utils_locales_locale_compare_lambda50__gequal_func (gconstpointer a,
                                                                    gconstpointer b);
VALA_EXTERN TubaUtilsLocalesLocale* tuba_utils_locales_locale_new (const gchar* locale,
                                                       const gchar* en_name,
                                                       const gchar* name);
VALA_EXTERN TubaUtilsLocalesLocale* tuba_utils_locales_locale_construct (GType object_type,
                                                             const gchar* locale,
                                                             const gchar* en_name,
                                                             const gchar* name);
VALA_EXTERN void tuba_utils_locales_locale_set_locale (TubaUtilsLocalesLocale* self,
                                           const gchar* value);
VALA_EXTERN const gchar* tuba_utils_locales_locale_get_en_name (TubaUtilsLocalesLocale* self);
VALA_EXTERN void tuba_utils_locales_locale_set_en_name (TubaUtilsLocalesLocale* self,
                                            const gchar* value);
VALA_EXTERN const gchar* tuba_utils_locales_locale_get_name (TubaUtilsLocalesLocale* self);
VALA_EXTERN void tuba_utils_locales_locale_set_name (TubaUtilsLocalesLocale* self,
                                         const gchar* value);
static void tuba_utils_locales_locale_finalize (GObject * obj);
static GType tuba_utils_locales_locale_get_type_once (void);
static void _vala_tuba_utils_locales_locale_get_property (GObject * object,
                                                   guint property_id,
                                                   GValue * value,
                                                   GParamSpec * pspec);
static void _vala_tuba_utils_locales_locale_set_property (GObject * object,
                                                   guint property_id,
                                                   const GValue * value,
                                                   GParamSpec * pspec);
static GObject * tuba_utils_locales_constructor (GType type,
                                          guint n_construct_properties,
                                          GObjectConstructParam * construct_properties);
static void tuba_utils_locales_finalize (GObject * obj);
static GType tuba_utils_locales_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

TubaUtilsLocales*
tuba_utils_locales_construct (GType object_type)
{
	TubaUtilsLocales * self = NULL;
	self = (TubaUtilsLocales*) g_object_new (object_type, NULL);
	return self;
}

TubaUtilsLocales*
tuba_utils_locales_new (void)
{
	return tuba_utils_locales_construct (TUBA_UTILS_TYPE_LOCALES);
}

static inline gpointer
tuba_utils_locales_locale_get_instance_private (TubaUtilsLocalesLocale* self)
{
	return G_STRUCT_MEMBER_P (self, TubaUtilsLocalesLocale_private_offset);
}

static gboolean
_tuba_utils_locales_locale_compare_lambda50_ (const gchar* a,
                                              const gchar* b)
{
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gboolean result;
	g_return_val_if_fail (a != NULL, FALSE);
	g_return_val_if_fail (b != NULL, FALSE);
	_tmp0_ = G_TYPE_CHECK_INSTANCE_CAST (a, TUBA_UTILS_LOCALES_TYPE_LOCALE, TubaUtilsLocalesLocale)->priv->_locale;
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (b, TUBA_UTILS_LOCALES_TYPE_LOCALE, TubaUtilsLocalesLocale)->priv->_locale;
	result = g_strcmp0 (_tmp0_, _tmp1_) == 0;
	return result;
}

static gboolean
__tuba_utils_locales_locale_compare_lambda50__gequal_func (gconstpointer a,
                                                           gconstpointer b)
{
	gboolean result;
	result = _tuba_utils_locales_locale_compare_lambda50_ ((const gchar*) a, (const gchar*) b);
	return result;
}

TubaUtilsLocalesLocale*
tuba_utils_locales_locale_construct (GType object_type,
                                     const gchar* locale,
                                     const gchar* en_name,
                                     const gchar* name)
{
	TubaUtilsLocalesLocale * self = NULL;
	self = (TubaUtilsLocalesLocale*) g_object_new (object_type, "locale", locale, "en-name", en_name, "name", name, NULL);
	return self;
}

TubaUtilsLocalesLocale*
tuba_utils_locales_locale_new (const gchar* locale,
                               const gchar* en_name,
                               const gchar* name)
{
	return tuba_utils_locales_locale_construct (TUBA_UTILS_LOCALES_TYPE_LOCALE, locale, en_name, name);
}

const gchar*
tuba_utils_locales_locale_get_locale (TubaUtilsLocalesLocale* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_locale;
	result = _tmp0_;
	return result;
}

void
tuba_utils_locales_locale_set_locale (TubaUtilsLocalesLocale* self,
                                      const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_utils_locales_locale_get_locale (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_locale);
		self->priv->_locale = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_utils_locales_locale_properties[TUBA_UTILS_LOCALES_LOCALE_LOCALE_PROPERTY]);
	}
}

const gchar*
tuba_utils_locales_locale_get_en_name (TubaUtilsLocalesLocale* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_en_name;
	result = _tmp0_;
	return result;
}

void
tuba_utils_locales_locale_set_en_name (TubaUtilsLocalesLocale* self,
                                       const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_utils_locales_locale_get_en_name (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_en_name);
		self->priv->_en_name = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_utils_locales_locale_properties[TUBA_UTILS_LOCALES_LOCALE_EN_NAME_PROPERTY]);
	}
}

const gchar*
tuba_utils_locales_locale_get_name (TubaUtilsLocalesLocale* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_name;
	result = _tmp0_;
	return result;
}

void
tuba_utils_locales_locale_set_name (TubaUtilsLocalesLocale* self,
                                    const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_utils_locales_locale_get_name (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_name);
		self->priv->_name = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_utils_locales_locale_properties[TUBA_UTILS_LOCALES_LOCALE_NAME_PROPERTY]);
	}
}

static void
tuba_utils_locales_locale_class_init (TubaUtilsLocalesLocaleClass * klass,
                                      gpointer klass_data)
{
	tuba_utils_locales_locale_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaUtilsLocalesLocale_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_utils_locales_locale_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_utils_locales_locale_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_utils_locales_locale_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_UTILS_LOCALES_LOCALE_LOCALE_PROPERTY, tuba_utils_locales_locale_properties[TUBA_UTILS_LOCALES_LOCALE_LOCALE_PROPERTY] = g_param_spec_string ("locale", "locale", "locale", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_UTILS_LOCALES_LOCALE_EN_NAME_PROPERTY, tuba_utils_locales_locale_properties[TUBA_UTILS_LOCALES_LOCALE_EN_NAME_PROPERTY] = g_param_spec_string ("en-name", "en-name", "en-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_UTILS_LOCALES_LOCALE_NAME_PROPERTY, tuba_utils_locales_locale_properties[TUBA_UTILS_LOCALES_LOCALE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	tuba_utils_locales_locale_compare = __tuba_utils_locales_locale_compare_lambda50__gequal_func;
}

static void
tuba_utils_locales_locale_instance_init (TubaUtilsLocalesLocale * self,
                                         gpointer klass)
{
	self->priv = tuba_utils_locales_locale_get_instance_private (self);
}

static void
tuba_utils_locales_locale_finalize (GObject * obj)
{
	TubaUtilsLocalesLocale * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_UTILS_LOCALES_TYPE_LOCALE, TubaUtilsLocalesLocale);
	_g_free0 (self->priv->_locale);
	_g_free0 (self->priv->_en_name);
	_g_free0 (self->priv->_name);
	G_OBJECT_CLASS (tuba_utils_locales_locale_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_utils_locales_locale_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaUtilsLocalesLocaleClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_utils_locales_locale_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaUtilsLocalesLocale), 0, (GInstanceInitFunc) tuba_utils_locales_locale_instance_init, NULL };
	GType tuba_utils_locales_locale_type_id;
	tuba_utils_locales_locale_type_id = g_type_register_static (G_TYPE_OBJECT, "TubaUtilsLocalesLocale", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaUtilsLocalesLocale_private_offset = g_type_add_instance_private (tuba_utils_locales_locale_type_id, sizeof (TubaUtilsLocalesLocalePrivate));
	return tuba_utils_locales_locale_type_id;
}

GType
tuba_utils_locales_locale_get_type (void)
{
	static GType tuba_utils_locales_locale_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_utils_locales_locale_type_id__once)) {
		GType tuba_utils_locales_locale_type_id;
		tuba_utils_locales_locale_type_id = tuba_utils_locales_locale_get_type_once ();
		g_once_init_leave_pointer (&tuba_utils_locales_locale_type_id__once, tuba_utils_locales_locale_type_id);
	}
	return tuba_utils_locales_locale_type_id__once;
}

static void
_vala_tuba_utils_locales_locale_get_property (GObject * object,
                                              guint property_id,
                                              GValue * value,
                                              GParamSpec * pspec)
{
	TubaUtilsLocalesLocale * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_UTILS_LOCALES_TYPE_LOCALE, TubaUtilsLocalesLocale);
	switch (property_id) {
		case TUBA_UTILS_LOCALES_LOCALE_LOCALE_PROPERTY:
		g_value_set_string (value, tuba_utils_locales_locale_get_locale (self));
		break;
		case TUBA_UTILS_LOCALES_LOCALE_EN_NAME_PROPERTY:
		g_value_set_string (value, tuba_utils_locales_locale_get_en_name (self));
		break;
		case TUBA_UTILS_LOCALES_LOCALE_NAME_PROPERTY:
		g_value_set_string (value, tuba_utils_locales_locale_get_name (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_utils_locales_locale_set_property (GObject * object,
                                              guint property_id,
                                              const GValue * value,
                                              GParamSpec * pspec)
{
	TubaUtilsLocalesLocale * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_UTILS_LOCALES_TYPE_LOCALE, TubaUtilsLocalesLocale);
	switch (property_id) {
		case TUBA_UTILS_LOCALES_LOCALE_LOCALE_PROPERTY:
		tuba_utils_locales_locale_set_locale (self, g_value_get_string (value));
		break;
		case TUBA_UTILS_LOCALES_LOCALE_EN_NAME_PROPERTY:
		tuba_utils_locales_locale_set_en_name (self, g_value_get_string (value));
		break;
		case TUBA_UTILS_LOCALES_LOCALE_NAME_PROPERTY:
		tuba_utils_locales_locale_set_name (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static GObject *
tuba_utils_locales_constructor (GType type,
                                guint n_construct_properties,
                                GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaUtilsLocales * self;
	GListStore* _tmp0_;
	TubaUtilsLocalesLocale* _tmp1_;
	TubaUtilsLocalesLocale* _tmp2_;
	TubaUtilsLocalesLocale* _tmp3_;
	TubaUtilsLocalesLocale* _tmp4_;
	TubaUtilsLocalesLocale* _tmp5_;
	TubaUtilsLocalesLocale* _tmp6_;
	TubaUtilsLocalesLocale* _tmp7_;
	TubaUtilsLocalesLocale* _tmp8_;
	TubaUtilsLocalesLocale* _tmp9_;
	TubaUtilsLocalesLocale* _tmp10_;
	TubaUtilsLocalesLocale* _tmp11_;
	TubaUtilsLocalesLocale* _tmp12_;
	TubaUtilsLocalesLocale* _tmp13_;
	TubaUtilsLocalesLocale* _tmp14_;
	TubaUtilsLocalesLocale* _tmp15_;
	TubaUtilsLocalesLocale* _tmp16_;
	TubaUtilsLocalesLocale* _tmp17_;
	TubaUtilsLocalesLocale* _tmp18_;
	TubaUtilsLocalesLocale* _tmp19_;
	TubaUtilsLocalesLocale* _tmp20_;
	TubaUtilsLocalesLocale* _tmp21_;
	TubaUtilsLocalesLocale* _tmp22_;
	TubaUtilsLocalesLocale* _tmp23_;
	TubaUtilsLocalesLocale* _tmp24_;
	TubaUtilsLocalesLocale* _tmp25_;
	TubaUtilsLocalesLocale* _tmp26_;
	TubaUtilsLocalesLocale* _tmp27_;
	TubaUtilsLocalesLocale* _tmp28_;
	TubaUtilsLocalesLocale* _tmp29_;
	TubaUtilsLocalesLocale* _tmp30_;
	TubaUtilsLocalesLocale* _tmp31_;
	TubaUtilsLocalesLocale* _tmp32_;
	TubaUtilsLocalesLocale* _tmp33_;
	TubaUtilsLocalesLocale* _tmp34_;
	TubaUtilsLocalesLocale* _tmp35_;
	TubaUtilsLocalesLocale* _tmp36_;
	TubaUtilsLocalesLocale* _tmp37_;
	TubaUtilsLocalesLocale* _tmp38_;
	TubaUtilsLocalesLocale* _tmp39_;
	TubaUtilsLocalesLocale* _tmp40_;
	TubaUtilsLocalesLocale* _tmp41_;
	TubaUtilsLocalesLocale* _tmp42_;
	TubaUtilsLocalesLocale* _tmp43_;
	TubaUtilsLocalesLocale* _tmp44_;
	TubaUtilsLocalesLocale* _tmp45_;
	TubaUtilsLocalesLocale* _tmp46_;
	TubaUtilsLocalesLocale* _tmp47_;
	TubaUtilsLocalesLocale* _tmp48_;
	TubaUtilsLocalesLocale* _tmp49_;
	TubaUtilsLocalesLocale* _tmp50_;
	TubaUtilsLocalesLocale* _tmp51_;
	TubaUtilsLocalesLocale* _tmp52_;
	TubaUtilsLocalesLocale* _tmp53_;
	TubaUtilsLocalesLocale* _tmp54_;
	TubaUtilsLocalesLocale* _tmp55_;
	TubaUtilsLocalesLocale* _tmp56_;
	TubaUtilsLocalesLocale* _tmp57_;
	TubaUtilsLocalesLocale* _tmp58_;
	TubaUtilsLocalesLocale* _tmp59_;
	TubaUtilsLocalesLocale* _tmp60_;
	TubaUtilsLocalesLocale* _tmp61_;
	TubaUtilsLocalesLocale* _tmp62_;
	TubaUtilsLocalesLocale* _tmp63_;
	TubaUtilsLocalesLocale* _tmp64_;
	TubaUtilsLocalesLocale* _tmp65_;
	TubaUtilsLocalesLocale* _tmp66_;
	TubaUtilsLocalesLocale* _tmp67_;
	TubaUtilsLocalesLocale* _tmp68_;
	TubaUtilsLocalesLocale* _tmp69_;
	TubaUtilsLocalesLocale* _tmp70_;
	TubaUtilsLocalesLocale* _tmp71_;
	TubaUtilsLocalesLocale* _tmp72_;
	TubaUtilsLocalesLocale* _tmp73_;
	TubaUtilsLocalesLocale* _tmp74_;
	TubaUtilsLocalesLocale* _tmp75_;
	TubaUtilsLocalesLocale* _tmp76_;
	TubaUtilsLocalesLocale* _tmp77_;
	TubaUtilsLocalesLocale* _tmp78_;
	TubaUtilsLocalesLocale* _tmp79_;
	TubaUtilsLocalesLocale* _tmp80_;
	TubaUtilsLocalesLocale* _tmp81_;
	TubaUtilsLocalesLocale* _tmp82_;
	TubaUtilsLocalesLocale* _tmp83_;
	TubaUtilsLocalesLocale* _tmp84_;
	TubaUtilsLocalesLocale* _tmp85_;
	TubaUtilsLocalesLocale* _tmp86_;
	TubaUtilsLocalesLocale* _tmp87_;
	TubaUtilsLocalesLocale* _tmp88_;
	TubaUtilsLocalesLocale* _tmp89_;
	TubaUtilsLocalesLocale* _tmp90_;
	TubaUtilsLocalesLocale* _tmp91_;
	TubaUtilsLocalesLocale* _tmp92_;
	TubaUtilsLocalesLocale* _tmp93_;
	TubaUtilsLocalesLocale* _tmp94_;
	TubaUtilsLocalesLocale* _tmp95_;
	TubaUtilsLocalesLocale* _tmp96_;
	TubaUtilsLocalesLocale* _tmp97_;
	TubaUtilsLocalesLocale* _tmp98_;
	TubaUtilsLocalesLocale* _tmp99_;
	TubaUtilsLocalesLocale* _tmp100_;
	TubaUtilsLocalesLocale* _tmp101_;
	TubaUtilsLocalesLocale* _tmp102_;
	TubaUtilsLocalesLocale* _tmp103_;
	TubaUtilsLocalesLocale* _tmp104_;
	TubaUtilsLocalesLocale* _tmp105_;
	TubaUtilsLocalesLocale* _tmp106_;
	TubaUtilsLocalesLocale* _tmp107_;
	TubaUtilsLocalesLocale* _tmp108_;
	TubaUtilsLocalesLocale* _tmp109_;
	TubaUtilsLocalesLocale* _tmp110_;
	TubaUtilsLocalesLocale* _tmp111_;
	TubaUtilsLocalesLocale* _tmp112_;
	TubaUtilsLocalesLocale* _tmp113_;
	TubaUtilsLocalesLocale* _tmp114_;
	TubaUtilsLocalesLocale* _tmp115_;
	TubaUtilsLocalesLocale* _tmp116_;
	TubaUtilsLocalesLocale* _tmp117_;
	TubaUtilsLocalesLocale* _tmp118_;
	TubaUtilsLocalesLocale* _tmp119_;
	TubaUtilsLocalesLocale* _tmp120_;
	TubaUtilsLocalesLocale* _tmp121_;
	TubaUtilsLocalesLocale* _tmp122_;
	TubaUtilsLocalesLocale* _tmp123_;
	TubaUtilsLocalesLocale* _tmp124_;
	TubaUtilsLocalesLocale* _tmp125_;
	TubaUtilsLocalesLocale* _tmp126_;
	TubaUtilsLocalesLocale* _tmp127_;
	TubaUtilsLocalesLocale* _tmp128_;
	TubaUtilsLocalesLocale* _tmp129_;
	TubaUtilsLocalesLocale* _tmp130_;
	TubaUtilsLocalesLocale* _tmp131_;
	TubaUtilsLocalesLocale* _tmp132_;
	TubaUtilsLocalesLocale* _tmp133_;
	TubaUtilsLocalesLocale* _tmp134_;
	TubaUtilsLocalesLocale* _tmp135_;
	TubaUtilsLocalesLocale* _tmp136_;
	TubaUtilsLocalesLocale* _tmp137_;
	TubaUtilsLocalesLocale* _tmp138_;
	TubaUtilsLocalesLocale* _tmp139_;
	TubaUtilsLocalesLocale* _tmp140_;
	TubaUtilsLocalesLocale* _tmp141_;
	TubaUtilsLocalesLocale* _tmp142_;
	TubaUtilsLocalesLocale* _tmp143_;
	TubaUtilsLocalesLocale* _tmp144_;
	TubaUtilsLocalesLocale* _tmp145_;
	TubaUtilsLocalesLocale* _tmp146_;
	TubaUtilsLocalesLocale* _tmp147_;
	TubaUtilsLocalesLocale* _tmp148_;
	TubaUtilsLocalesLocale* _tmp149_;
	TubaUtilsLocalesLocale* _tmp150_;
	TubaUtilsLocalesLocale* _tmp151_;
	TubaUtilsLocalesLocale* _tmp152_;
	TubaUtilsLocalesLocale* _tmp153_;
	TubaUtilsLocalesLocale* _tmp154_;
	TubaUtilsLocalesLocale* _tmp155_;
	TubaUtilsLocalesLocale* _tmp156_;
	TubaUtilsLocalesLocale* _tmp157_;
	TubaUtilsLocalesLocale* _tmp158_;
	TubaUtilsLocalesLocale* _tmp159_;
	TubaUtilsLocalesLocale* _tmp160_;
	TubaUtilsLocalesLocale* _tmp161_;
	TubaUtilsLocalesLocale* _tmp162_;
	TubaUtilsLocalesLocale* _tmp163_;
	TubaUtilsLocalesLocale* _tmp164_;
	TubaUtilsLocalesLocale* _tmp165_;
	TubaUtilsLocalesLocale* _tmp166_;
	TubaUtilsLocalesLocale* _tmp167_;
	TubaUtilsLocalesLocale* _tmp168_;
	TubaUtilsLocalesLocale* _tmp169_;
	TubaUtilsLocalesLocale* _tmp170_;
	TubaUtilsLocalesLocale* _tmp171_;
	TubaUtilsLocalesLocale* _tmp172_;
	TubaUtilsLocalesLocale* _tmp173_;
	TubaUtilsLocalesLocale* _tmp174_;
	TubaUtilsLocalesLocale* _tmp175_;
	TubaUtilsLocalesLocale* _tmp176_;
	TubaUtilsLocalesLocale* _tmp177_;
	TubaUtilsLocalesLocale* _tmp178_;
	TubaUtilsLocalesLocale* _tmp179_;
	TubaUtilsLocalesLocale* _tmp180_;
	TubaUtilsLocalesLocale* _tmp181_;
	TubaUtilsLocalesLocale* _tmp182_;
	TubaUtilsLocalesLocale* _tmp183_;
	TubaUtilsLocalesLocale* _tmp184_;
	TubaUtilsLocalesLocale* _tmp185_;
	TubaUtilsLocalesLocale* _tmp186_;
	TubaUtilsLocalesLocale* _tmp187_;
	TubaUtilsLocalesLocale* _tmp188_;
	TubaUtilsLocalesLocale* _tmp189_;
	TubaUtilsLocalesLocale* _tmp190_;
	TubaUtilsLocalesLocale* _tmp191_;
	TubaUtilsLocalesLocale* _tmp192_;
	TubaUtilsLocalesLocale* _tmp193_;
	TubaUtilsLocalesLocale* _tmp194_;
	TubaUtilsLocalesLocale* _tmp195_;
	TubaUtilsLocalesLocale* _tmp196_;
	TubaUtilsLocalesLocale* _tmp197_;
	TubaUtilsLocalesLocale* _tmp198_;
	GObject** _tmp199_;
	GObject** _tmp200_;
	gint _tmp200__length1;
	parent_class = G_OBJECT_CLASS (tuba_utils_locales_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_UTILS_TYPE_LOCALES, TubaUtilsLocales);
	_tmp0_ = self->list_store;
	_tmp1_ = tuba_utils_locales_locale_new ("aa", "Afar", "Afaraf");
	_tmp2_ = tuba_utils_locales_locale_new ("ab", "Abkhaz", "аҧсуа бызшәа");
	_tmp3_ = tuba_utils_locales_locale_new ("ae", "Avestan", "avesta");
	_tmp4_ = tuba_utils_locales_locale_new ("af", "Afrikaans", "Afrikaans");
	_tmp5_ = tuba_utils_locales_locale_new ("ak", "Akan", "Akan");
	_tmp6_ = tuba_utils_locales_locale_new ("am", "Amharic", "አማርኛ");
	_tmp7_ = tuba_utils_locales_locale_new ("an", "Aragonese", "aragonés");
	_tmp8_ = tuba_utils_locales_locale_new ("ar", "Arabic", "اللغة العربية");
	_tmp9_ = tuba_utils_locales_locale_new ("as", "Assamese", "অসমীয়া");
	_tmp10_ = tuba_utils_locales_locale_new ("ast", "Asturian", "Asturianu");
	_tmp11_ = tuba_utils_locales_locale_new ("av", "Avaric", "авар мацӀ");
	_tmp12_ = tuba_utils_locales_locale_new ("ay", "Aymara", "aymar aru");
	_tmp13_ = tuba_utils_locales_locale_new ("az", "Azerbaijani", "azərbaycan dili");
	_tmp14_ = tuba_utils_locales_locale_new ("ba", "Bashkir", "башҡорт теле");
	_tmp15_ = tuba_utils_locales_locale_new ("be", "Belarusian", "беларуская мова");
	_tmp16_ = tuba_utils_locales_locale_new ("bg", "Bulgarian", "български език");
	_tmp17_ = tuba_utils_locales_locale_new ("bh", "Bihari", "भोजपुरी");
	_tmp18_ = tuba_utils_locales_locale_new ("bi", "Bislama", "Bislama");
	_tmp19_ = tuba_utils_locales_locale_new ("bm", "Bambara", "bamanankan");
	_tmp20_ = tuba_utils_locales_locale_new ("bn", "Bengali", "বাংলা");
	_tmp21_ = tuba_utils_locales_locale_new ("bo", "Tibetan", "བོད་ཡིག");
	_tmp22_ = tuba_utils_locales_locale_new ("br", "Breton", "brezhoneg");
	_tmp23_ = tuba_utils_locales_locale_new ("bs", "Bosnian", "bosanski jezik");
	_tmp24_ = tuba_utils_locales_locale_new ("ca", "Catalan", "Català");
	_tmp25_ = tuba_utils_locales_locale_new ("ce", "Chechen", "нохчийн мотт");
	_tmp26_ = tuba_utils_locales_locale_new ("ch", "Chamorro", "Chamoru");
	_tmp27_ = tuba_utils_locales_locale_new ("ckb", "Sorani (Kurdish)", "سۆرانی");
	_tmp28_ = tuba_utils_locales_locale_new ("cnr", "Montenegrin", "crnogorski");
	_tmp29_ = tuba_utils_locales_locale_new ("co", "Corsican", "corsu");
	_tmp30_ = tuba_utils_locales_locale_new ("cr", "Cree", "ᓀᐦᐃᔭᐍᐏᐣ");
	_tmp31_ = tuba_utils_locales_locale_new ("cs", "Czech", "čeština");
	_tmp32_ = tuba_utils_locales_locale_new ("cu", "Old Church Slavonic", "ѩзыкъ словѣньскъ");
	_tmp33_ = tuba_utils_locales_locale_new ("cv", "Chuvash", "чӑваш чӗлхи");
	_tmp34_ = tuba_utils_locales_locale_new ("cy", "Welsh", "Cymraeg");
	_tmp35_ = tuba_utils_locales_locale_new ("da", "Danish", "dansk");
	_tmp36_ = tuba_utils_locales_locale_new ("de", "German", "Deutsch");
	_tmp37_ = tuba_utils_locales_locale_new ("dv", "Divehi", "Dhivehi");
	_tmp38_ = tuba_utils_locales_locale_new ("dz", "Dzongkha", "རྫོང་ཁ");
	_tmp39_ = tuba_utils_locales_locale_new ("ee", "Ewe", "Eʋegbe");
	_tmp40_ = tuba_utils_locales_locale_new ("el", "Greek", "Ελληνικά");
	_tmp41_ = tuba_utils_locales_locale_new ("en", "English", "English");
	_tmp42_ = tuba_utils_locales_locale_new ("eo", "Esperanto", "Esperanto");
	_tmp43_ = tuba_utils_locales_locale_new ("es", "Spanish", "Español");
	_tmp44_ = tuba_utils_locales_locale_new ("et", "Estonian", "eesti");
	_tmp45_ = tuba_utils_locales_locale_new ("eu", "Basque", "euskara");
	_tmp46_ = tuba_utils_locales_locale_new ("fa", "Persian", "فارسی");
	_tmp47_ = tuba_utils_locales_locale_new ("ff", "Fula", "Fulfulde");
	_tmp48_ = tuba_utils_locales_locale_new ("fi", "Finnish", "suomi");
	_tmp49_ = tuba_utils_locales_locale_new ("fj", "Fijian", "Vakaviti");
	_tmp50_ = tuba_utils_locales_locale_new ("fo", "Faroese", "føroyskt");
	_tmp51_ = tuba_utils_locales_locale_new ("fr", "French", "Français");
	_tmp52_ = tuba_utils_locales_locale_new ("fy", "Western Frisian", "Frysk");
	_tmp53_ = tuba_utils_locales_locale_new ("ga", "Irish", "Gaeilge");
	_tmp54_ = tuba_utils_locales_locale_new ("gd", "Scottish Gaelic", "Gàidhlig");
	_tmp55_ = tuba_utils_locales_locale_new ("gl", "Galician", "galego");
	_tmp56_ = tuba_utils_locales_locale_new ("gu", "Gujarati", "ગુજરાતી");
	_tmp57_ = tuba_utils_locales_locale_new ("gv", "Manx", "Gaelg");
	_tmp58_ = tuba_utils_locales_locale_new ("ha", "Hausa", "هَوُسَ");
	_tmp59_ = tuba_utils_locales_locale_new ("he", "Hebrew", "עברית");
	_tmp60_ = tuba_utils_locales_locale_new ("hi", "Hindi", "हिन्दी");
	_tmp61_ = tuba_utils_locales_locale_new ("ho", "Hiri Motu", "Hiri Motu");
	_tmp62_ = tuba_utils_locales_locale_new ("hr", "Croatian", "Hrvatski");
	_tmp63_ = tuba_utils_locales_locale_new ("ht", "Haitian", "Kreyòl ayisyen");
	_tmp64_ = tuba_utils_locales_locale_new ("hu", "Hungarian", "magyar");
	_tmp65_ = tuba_utils_locales_locale_new ("hy", "Armenian", "Հայերեն");
	_tmp66_ = tuba_utils_locales_locale_new ("hz", "Herero", "Otjiherero");
	_tmp67_ = tuba_utils_locales_locale_new ("ia", "Interlingua", "Interlingua");
	_tmp68_ = tuba_utils_locales_locale_new ("id", "Indonesian", "Bahasa Indonesia");
	_tmp69_ = tuba_utils_locales_locale_new ("ie", "Interlingue", "Interlingue");
	_tmp70_ = tuba_utils_locales_locale_new ("ig", "Igbo", "Asụsụ Igbo");
	_tmp71_ = tuba_utils_locales_locale_new ("ii", "Nuosu", "ꆈꌠ꒿ Nuosuhxop");
	_tmp72_ = tuba_utils_locales_locale_new ("ik", "Inupiaq", "Iñupiaq");
	_tmp73_ = tuba_utils_locales_locale_new ("io", "Ido", "Ido");
	_tmp74_ = tuba_utils_locales_locale_new ("is", "Icelandic", "Íslenska");
	_tmp75_ = tuba_utils_locales_locale_new ("it", "Italian", "Italiano");
	_tmp76_ = tuba_utils_locales_locale_new ("iu", "Inuktitut", "ᐃᓄᒃᑎᑐᑦ");
	_tmp77_ = tuba_utils_locales_locale_new ("ja", "Japanese", "日本語");
	_tmp78_ = tuba_utils_locales_locale_new ("jbo", "Lojban", "la .lojban.");
	_tmp79_ = tuba_utils_locales_locale_new ("jv", "Javanese", "basa Jawa");
	_tmp80_ = tuba_utils_locales_locale_new ("ka", "Georgian", "ქართული");
	_tmp81_ = tuba_utils_locales_locale_new ("kab", "Kabyle", "Taqbaylit");
	_tmp82_ = tuba_utils_locales_locale_new ("kg", "Kongo", "Kikongo");
	_tmp83_ = tuba_utils_locales_locale_new ("ki", "Kikuyu", "Gĩkũyũ");
	_tmp84_ = tuba_utils_locales_locale_new ("kj", "Kwanyama", "Kuanyama");
	_tmp85_ = tuba_utils_locales_locale_new ("kk", "Kazakh", "қазақ тілі");
	_tmp86_ = tuba_utils_locales_locale_new ("kl", "Kalaallisut", "kalaallisut");
	_tmp87_ = tuba_utils_locales_locale_new ("km", "Khmer", "ខេមរភាសា");
	_tmp88_ = tuba_utils_locales_locale_new ("kmr", "Kurmanji (Kurdish)", "Kurmancî");
	_tmp89_ = tuba_utils_locales_locale_new ("kn", "Kannada", "ಕನ್ನಡ");
	_tmp90_ = tuba_utils_locales_locale_new ("ko", "Korean", "한국어");
	_tmp91_ = tuba_utils_locales_locale_new ("kr", "Kanuri", "Kanuri");
	_tmp92_ = tuba_utils_locales_locale_new ("ks", "Kashmiri", "कश्मीरी");
	_tmp93_ = tuba_utils_locales_locale_new ("ku", "Kurmanji (Kurdish)", "Kurmancî");
	_tmp94_ = tuba_utils_locales_locale_new ("kv", "Komi", "коми кыв");
	_tmp95_ = tuba_utils_locales_locale_new ("kw", "Cornish", "Kernewek");
	_tmp96_ = tuba_utils_locales_locale_new ("ky", "Kyrgyz", "Кыргызча");
	_tmp97_ = tuba_utils_locales_locale_new ("la", "Latin", "latine");
	_tmp98_ = tuba_utils_locales_locale_new ("lb", "Luxembourgish", "Lëtzebuergesch");
	_tmp99_ = tuba_utils_locales_locale_new ("ldn", "Láadan", "Láadan");
	_tmp100_ = tuba_utils_locales_locale_new ("lfn", "Lingua Franca Nova", "lingua franca nova");
	_tmp101_ = tuba_utils_locales_locale_new ("lg", "Ganda", "Luganda");
	_tmp102_ = tuba_utils_locales_locale_new ("li", "Limburgish", "Limburgs");
	_tmp103_ = tuba_utils_locales_locale_new ("ln", "Lingala", "Lingála");
	_tmp104_ = tuba_utils_locales_locale_new ("lo", "Lao", "ລາວ");
	_tmp105_ = tuba_utils_locales_locale_new ("lt", "Lithuanian", "lietuvių kalba");
	_tmp106_ = tuba_utils_locales_locale_new ("lu", "Luba-Katanga", "Tshiluba");
	_tmp107_ = tuba_utils_locales_locale_new ("lv", "Latvian", "latviešu valoda");
	_tmp108_ = tuba_utils_locales_locale_new ("mg", "Malagasy", "fiteny malagasy");
	_tmp109_ = tuba_utils_locales_locale_new ("mh", "Marshallese", "Kajin M̧ajeļ");
	_tmp110_ = tuba_utils_locales_locale_new ("mi", "Māori", "te reo Māori");
	_tmp111_ = tuba_utils_locales_locale_new ("mk", "Macedonian", "македонски јазик");
	_tmp112_ = tuba_utils_locales_locale_new ("ml", "Malayalam", "മലയാളം");
	_tmp113_ = tuba_utils_locales_locale_new ("mn", "Mongolian", "Монгол хэл");
	_tmp114_ = tuba_utils_locales_locale_new ("mr", "Marathi", "मराठी");
	_tmp115_ = tuba_utils_locales_locale_new ("ms", "Malay", "Bahasa Melayu");
	_tmp116_ = tuba_utils_locales_locale_new ("mt", "Maltese", "Malti");
	_tmp117_ = tuba_utils_locales_locale_new ("my", "Burmese", "ဗမာစာ");
	_tmp118_ = tuba_utils_locales_locale_new ("na", "Nauru", "Ekakairũ Naoero");
	_tmp119_ = tuba_utils_locales_locale_new ("nb", "Norwegian Bokmål", "Norsk bokmål");
	_tmp120_ = tuba_utils_locales_locale_new ("nd", "Northern Ndebele", "isiNdebele");
	_tmp121_ = tuba_utils_locales_locale_new ("ne", "Nepali", "नेपाली");
	_tmp122_ = tuba_utils_locales_locale_new ("ng", "Ndonga", "Owambo");
	_tmp123_ = tuba_utils_locales_locale_new ("nl", "Dutch", "Nederlands");
	_tmp124_ = tuba_utils_locales_locale_new ("nn", "Norwegian Nynorsk", "Norsk Nynorsk");
	_tmp125_ = tuba_utils_locales_locale_new ("no", "Norwegian", "Norsk");
	_tmp126_ = tuba_utils_locales_locale_new ("nr", "Southern Ndebele", "isiNdebele");
	_tmp127_ = tuba_utils_locales_locale_new ("nv", "Navajo", "Diné bizaad");
	_tmp128_ = tuba_utils_locales_locale_new ("ny", "Chichewa", "chiCheŵa");
	_tmp129_ = tuba_utils_locales_locale_new ("oc", "Occitan", "occitan");
	_tmp130_ = tuba_utils_locales_locale_new ("oj", "Ojibwe", "ᐊᓂᔑᓈᐯᒧᐎᓐ");
	_tmp131_ = tuba_utils_locales_locale_new ("om", "Oromo", "Afaan Oromoo");
	_tmp132_ = tuba_utils_locales_locale_new ("or", "Oriya", "ଓଡ଼ିଆ");
	_tmp133_ = tuba_utils_locales_locale_new ("os", "Ossetian", "ирон æвзаг");
	_tmp134_ = tuba_utils_locales_locale_new ("pa", "Panjabi", "ਪੰਜਾਬੀ");
	_tmp135_ = tuba_utils_locales_locale_new ("pi", "Pāli", "पाऴि");
	_tmp136_ = tuba_utils_locales_locale_new ("pl", "Polish", "Polski");
	_tmp137_ = tuba_utils_locales_locale_new ("ps", "Pashto", "پښتو");
	_tmp138_ = tuba_utils_locales_locale_new ("pt", "Portuguese", "Português");
	_tmp139_ = tuba_utils_locales_locale_new ("qu", "Quechua", "Runa Simi");
	_tmp140_ = tuba_utils_locales_locale_new ("rm", "Romansh", "rumantsch grischun");
	_tmp141_ = tuba_utils_locales_locale_new ("rn", "Kirundi", "Ikirundi");
	_tmp142_ = tuba_utils_locales_locale_new ("ro", "Romanian", "Română");
	_tmp143_ = tuba_utils_locales_locale_new ("ru", "Russian", "Русский");
	_tmp144_ = tuba_utils_locales_locale_new ("rw", "Kinyarwanda", "Ikinyarwanda");
	_tmp145_ = tuba_utils_locales_locale_new ("sa", "Sanskrit", "संस्कृतम्");
	_tmp146_ = tuba_utils_locales_locale_new ("sc", "Sardinian", "sardu");
	_tmp147_ = tuba_utils_locales_locale_new ("sco", "Scots", "Scots");
	_tmp148_ = tuba_utils_locales_locale_new ("sd", "Sindhi", "सिन्धी");
	_tmp149_ = tuba_utils_locales_locale_new ("se", "Northern Sami", "Davvisámegiella");
	_tmp150_ = tuba_utils_locales_locale_new ("sg", "Sango", "yângâ tî sängö");
	_tmp151_ = tuba_utils_locales_locale_new ("si", "Sinhala", "සිංහල");
	_tmp152_ = tuba_utils_locales_locale_new ("sk", "Slovak", "slovenčina");
	_tmp153_ = tuba_utils_locales_locale_new ("sl", "Slovenian", "slovenščina");
	_tmp154_ = tuba_utils_locales_locale_new ("sma", "Southern Sami", "Åarjelsaemien Gïele");
	_tmp155_ = tuba_utils_locales_locale_new ("smj", "Lule Sami", "Julevsámegiella");
	_tmp156_ = tuba_utils_locales_locale_new ("sn", "Shona", "chiShona");
	_tmp157_ = tuba_utils_locales_locale_new ("so", "Somali", "Soomaaliga");
	_tmp158_ = tuba_utils_locales_locale_new ("sq", "Albanian", "Shqip");
	_tmp159_ = tuba_utils_locales_locale_new ("sr", "Serbian", "српски језик");
	_tmp160_ = tuba_utils_locales_locale_new ("ss", "Swati", "SiSwati");
	_tmp161_ = tuba_utils_locales_locale_new ("st", "Southern Sotho", "Sesotho");
	_tmp162_ = tuba_utils_locales_locale_new ("su", "Sundanese", "Basa Sunda");
	_tmp163_ = tuba_utils_locales_locale_new ("sv", "Swedish", "Svenska");
	_tmp164_ = tuba_utils_locales_locale_new ("sw", "Swahili", "Kiswahili");
	_tmp165_ = tuba_utils_locales_locale_new ("szl", "Silesian", "ślůnsko godka");
	_tmp166_ = tuba_utils_locales_locale_new ("ta", "Tamil", "தமிழ்");
	_tmp167_ = tuba_utils_locales_locale_new ("tai", "Tai", "ภาษาไท or ภาษาไต");
	_tmp168_ = tuba_utils_locales_locale_new ("te", "Telugu", "తెలుగు");
	_tmp169_ = tuba_utils_locales_locale_new ("tg", "Tajik", "тоҷикӣ");
	_tmp170_ = tuba_utils_locales_locale_new ("th", "Thai", "ไทย");
	_tmp171_ = tuba_utils_locales_locale_new ("ti", "Tigrinya", "ትግርኛ");
	_tmp172_ = tuba_utils_locales_locale_new ("tk", "Turkmen", "Türkmen");
	_tmp173_ = tuba_utils_locales_locale_new ("tl", "Tagalog", "Wikang Tagalog");
	_tmp174_ = tuba_utils_locales_locale_new ("tn", "Tswana", "Setswana");
	_tmp175_ = tuba_utils_locales_locale_new ("to", "Tonga", "faka Tonga");
	_tmp176_ = tuba_utils_locales_locale_new ("tok", "Toki Pona", "toki pona");
	_tmp177_ = tuba_utils_locales_locale_new ("tr", "Turkish", "Türkçe");
	_tmp178_ = tuba_utils_locales_locale_new ("ts", "Tsonga", "Xitsonga");
	_tmp179_ = tuba_utils_locales_locale_new ("tt", "Tatar", "татар теле");
	_tmp180_ = tuba_utils_locales_locale_new ("tw", "Twi", "Twi");
	_tmp181_ = tuba_utils_locales_locale_new ("ty", "Tahitian", "Reo Tahiti");
	_tmp182_ = tuba_utils_locales_locale_new ("ug", "Uyghur", "ئۇيغۇرچە‎");
	_tmp183_ = tuba_utils_locales_locale_new ("uk", "Ukrainian", "Українська");
	_tmp184_ = tuba_utils_locales_locale_new ("ur", "Urdu", "اردو");
	_tmp185_ = tuba_utils_locales_locale_new ("uz", "Uzbek", "Ўзбек");
	_tmp186_ = tuba_utils_locales_locale_new ("ve", "Venda", "Tshivenḓa");
	_tmp187_ = tuba_utils_locales_locale_new ("vi", "Vietnamese", "Tiếng Việt");
	_tmp188_ = tuba_utils_locales_locale_new ("vo", "Volapük", "Volapük");
	_tmp189_ = tuba_utils_locales_locale_new ("wa", "Walloon", "walon");
	_tmp190_ = tuba_utils_locales_locale_new ("wo", "Wolof", "Wollof");
	_tmp191_ = tuba_utils_locales_locale_new ("xh", "Xhosa", "isiXhosa");
	_tmp192_ = tuba_utils_locales_locale_new ("yi", "Yiddish", "ייִדיש");
	_tmp193_ = tuba_utils_locales_locale_new ("yo", "Yoruba", "Yorùbá");
	_tmp194_ = tuba_utils_locales_locale_new ("za", "Zhuang", "Saɯ cueŋƅ");
	_tmp195_ = tuba_utils_locales_locale_new ("zba", "Balaibalan", "باليبلن");
	_tmp196_ = tuba_utils_locales_locale_new ("zgh", "Standard Moroccan Tamazight", "ⵜⴰⵎⴰⵣⵉⵖⵜ");
	_tmp197_ = tuba_utils_locales_locale_new ("zh", "Chinese", "中文");
	_tmp198_ = tuba_utils_locales_locale_new ("zu", "Zulu", "isiZulu");
	_tmp199_ = g_new0 (GObject*, 198 + 1);
	_tmp199_[0] = (GObject*) _tmp1_;
	_tmp199_[1] = (GObject*) _tmp2_;
	_tmp199_[2] = (GObject*) _tmp3_;
	_tmp199_[3] = (GObject*) _tmp4_;
	_tmp199_[4] = (GObject*) _tmp5_;
	_tmp199_[5] = (GObject*) _tmp6_;
	_tmp199_[6] = (GObject*) _tmp7_;
	_tmp199_[7] = (GObject*) _tmp8_;
	_tmp199_[8] = (GObject*) _tmp9_;
	_tmp199_[9] = (GObject*) _tmp10_;
	_tmp199_[10] = (GObject*) _tmp11_;
	_tmp199_[11] = (GObject*) _tmp12_;
	_tmp199_[12] = (GObject*) _tmp13_;
	_tmp199_[13] = (GObject*) _tmp14_;
	_tmp199_[14] = (GObject*) _tmp15_;
	_tmp199_[15] = (GObject*) _tmp16_;
	_tmp199_[16] = (GObject*) _tmp17_;
	_tmp199_[17] = (GObject*) _tmp18_;
	_tmp199_[18] = (GObject*) _tmp19_;
	_tmp199_[19] = (GObject*) _tmp20_;
	_tmp199_[20] = (GObject*) _tmp21_;
	_tmp199_[21] = (GObject*) _tmp22_;
	_tmp199_[22] = (GObject*) _tmp23_;
	_tmp199_[23] = (GObject*) _tmp24_;
	_tmp199_[24] = (GObject*) _tmp25_;
	_tmp199_[25] = (GObject*) _tmp26_;
	_tmp199_[26] = (GObject*) _tmp27_;
	_tmp199_[27] = (GObject*) _tmp28_;
	_tmp199_[28] = (GObject*) _tmp29_;
	_tmp199_[29] = (GObject*) _tmp30_;
	_tmp199_[30] = (GObject*) _tmp31_;
	_tmp199_[31] = (GObject*) _tmp32_;
	_tmp199_[32] = (GObject*) _tmp33_;
	_tmp199_[33] = (GObject*) _tmp34_;
	_tmp199_[34] = (GObject*) _tmp35_;
	_tmp199_[35] = (GObject*) _tmp36_;
	_tmp199_[36] = (GObject*) _tmp37_;
	_tmp199_[37] = (GObject*) _tmp38_;
	_tmp199_[38] = (GObject*) _tmp39_;
	_tmp199_[39] = (GObject*) _tmp40_;
	_tmp199_[40] = (GObject*) _tmp41_;
	_tmp199_[41] = (GObject*) _tmp42_;
	_tmp199_[42] = (GObject*) _tmp43_;
	_tmp199_[43] = (GObject*) _tmp44_;
	_tmp199_[44] = (GObject*) _tmp45_;
	_tmp199_[45] = (GObject*) _tmp46_;
	_tmp199_[46] = (GObject*) _tmp47_;
	_tmp199_[47] = (GObject*) _tmp48_;
	_tmp199_[48] = (GObject*) _tmp49_;
	_tmp199_[49] = (GObject*) _tmp50_;
	_tmp199_[50] = (GObject*) _tmp51_;
	_tmp199_[51] = (GObject*) _tmp52_;
	_tmp199_[52] = (GObject*) _tmp53_;
	_tmp199_[53] = (GObject*) _tmp54_;
	_tmp199_[54] = (GObject*) _tmp55_;
	_tmp199_[55] = (GObject*) _tmp56_;
	_tmp199_[56] = (GObject*) _tmp57_;
	_tmp199_[57] = (GObject*) _tmp58_;
	_tmp199_[58] = (GObject*) _tmp59_;
	_tmp199_[59] = (GObject*) _tmp60_;
	_tmp199_[60] = (GObject*) _tmp61_;
	_tmp199_[61] = (GObject*) _tmp62_;
	_tmp199_[62] = (GObject*) _tmp63_;
	_tmp199_[63] = (GObject*) _tmp64_;
	_tmp199_[64] = (GObject*) _tmp65_;
	_tmp199_[65] = (GObject*) _tmp66_;
	_tmp199_[66] = (GObject*) _tmp67_;
	_tmp199_[67] = (GObject*) _tmp68_;
	_tmp199_[68] = (GObject*) _tmp69_;
	_tmp199_[69] = (GObject*) _tmp70_;
	_tmp199_[70] = (GObject*) _tmp71_;
	_tmp199_[71] = (GObject*) _tmp72_;
	_tmp199_[72] = (GObject*) _tmp73_;
	_tmp199_[73] = (GObject*) _tmp74_;
	_tmp199_[74] = (GObject*) _tmp75_;
	_tmp199_[75] = (GObject*) _tmp76_;
	_tmp199_[76] = (GObject*) _tmp77_;
	_tmp199_[77] = (GObject*) _tmp78_;
	_tmp199_[78] = (GObject*) _tmp79_;
	_tmp199_[79] = (GObject*) _tmp80_;
	_tmp199_[80] = (GObject*) _tmp81_;
	_tmp199_[81] = (GObject*) _tmp82_;
	_tmp199_[82] = (GObject*) _tmp83_;
	_tmp199_[83] = (GObject*) _tmp84_;
	_tmp199_[84] = (GObject*) _tmp85_;
	_tmp199_[85] = (GObject*) _tmp86_;
	_tmp199_[86] = (GObject*) _tmp87_;
	_tmp199_[87] = (GObject*) _tmp88_;
	_tmp199_[88] = (GObject*) _tmp89_;
	_tmp199_[89] = (GObject*) _tmp90_;
	_tmp199_[90] = (GObject*) _tmp91_;
	_tmp199_[91] = (GObject*) _tmp92_;
	_tmp199_[92] = (GObject*) _tmp93_;
	_tmp199_[93] = (GObject*) _tmp94_;
	_tmp199_[94] = (GObject*) _tmp95_;
	_tmp199_[95] = (GObject*) _tmp96_;
	_tmp199_[96] = (GObject*) _tmp97_;
	_tmp199_[97] = (GObject*) _tmp98_;
	_tmp199_[98] = (GObject*) _tmp99_;
	_tmp199_[99] = (GObject*) _tmp100_;
	_tmp199_[100] = (GObject*) _tmp101_;
	_tmp199_[101] = (GObject*) _tmp102_;
	_tmp199_[102] = (GObject*) _tmp103_;
	_tmp199_[103] = (GObject*) _tmp104_;
	_tmp199_[104] = (GObject*) _tmp105_;
	_tmp199_[105] = (GObject*) _tmp106_;
	_tmp199_[106] = (GObject*) _tmp107_;
	_tmp199_[107] = (GObject*) _tmp108_;
	_tmp199_[108] = (GObject*) _tmp109_;
	_tmp199_[109] = (GObject*) _tmp110_;
	_tmp199_[110] = (GObject*) _tmp111_;
	_tmp199_[111] = (GObject*) _tmp112_;
	_tmp199_[112] = (GObject*) _tmp113_;
	_tmp199_[113] = (GObject*) _tmp114_;
	_tmp199_[114] = (GObject*) _tmp115_;
	_tmp199_[115] = (GObject*) _tmp116_;
	_tmp199_[116] = (GObject*) _tmp117_;
	_tmp199_[117] = (GObject*) _tmp118_;
	_tmp199_[118] = (GObject*) _tmp119_;
	_tmp199_[119] = (GObject*) _tmp120_;
	_tmp199_[120] = (GObject*) _tmp121_;
	_tmp199_[121] = (GObject*) _tmp122_;
	_tmp199_[122] = (GObject*) _tmp123_;
	_tmp199_[123] = (GObject*) _tmp124_;
	_tmp199_[124] = (GObject*) _tmp125_;
	_tmp199_[125] = (GObject*) _tmp126_;
	_tmp199_[126] = (GObject*) _tmp127_;
	_tmp199_[127] = (GObject*) _tmp128_;
	_tmp199_[128] = (GObject*) _tmp129_;
	_tmp199_[129] = (GObject*) _tmp130_;
	_tmp199_[130] = (GObject*) _tmp131_;
	_tmp199_[131] = (GObject*) _tmp132_;
	_tmp199_[132] = (GObject*) _tmp133_;
	_tmp199_[133] = (GObject*) _tmp134_;
	_tmp199_[134] = (GObject*) _tmp135_;
	_tmp199_[135] = (GObject*) _tmp136_;
	_tmp199_[136] = (GObject*) _tmp137_;
	_tmp199_[137] = (GObject*) _tmp138_;
	_tmp199_[138] = (GObject*) _tmp139_;
	_tmp199_[139] = (GObject*) _tmp140_;
	_tmp199_[140] = (GObject*) _tmp141_;
	_tmp199_[141] = (GObject*) _tmp142_;
	_tmp199_[142] = (GObject*) _tmp143_;
	_tmp199_[143] = (GObject*) _tmp144_;
	_tmp199_[144] = (GObject*) _tmp145_;
	_tmp199_[145] = (GObject*) _tmp146_;
	_tmp199_[146] = (GObject*) _tmp147_;
	_tmp199_[147] = (GObject*) _tmp148_;
	_tmp199_[148] = (GObject*) _tmp149_;
	_tmp199_[149] = (GObject*) _tmp150_;
	_tmp199_[150] = (GObject*) _tmp151_;
	_tmp199_[151] = (GObject*) _tmp152_;
	_tmp199_[152] = (GObject*) _tmp153_;
	_tmp199_[153] = (GObject*) _tmp154_;
	_tmp199_[154] = (GObject*) _tmp155_;
	_tmp199_[155] = (GObject*) _tmp156_;
	_tmp199_[156] = (GObject*) _tmp157_;
	_tmp199_[157] = (GObject*) _tmp158_;
	_tmp199_[158] = (GObject*) _tmp159_;
	_tmp199_[159] = (GObject*) _tmp160_;
	_tmp199_[160] = (GObject*) _tmp161_;
	_tmp199_[161] = (GObject*) _tmp162_;
	_tmp199_[162] = (GObject*) _tmp163_;
	_tmp199_[163] = (GObject*) _tmp164_;
	_tmp199_[164] = (GObject*) _tmp165_;
	_tmp199_[165] = (GObject*) _tmp166_;
	_tmp199_[166] = (GObject*) _tmp167_;
	_tmp199_[167] = (GObject*) _tmp168_;
	_tmp199_[168] = (GObject*) _tmp169_;
	_tmp199_[169] = (GObject*) _tmp170_;
	_tmp199_[170] = (GObject*) _tmp171_;
	_tmp199_[171] = (GObject*) _tmp172_;
	_tmp199_[172] = (GObject*) _tmp173_;
	_tmp199_[173] = (GObject*) _tmp174_;
	_tmp199_[174] = (GObject*) _tmp175_;
	_tmp199_[175] = (GObject*) _tmp176_;
	_tmp199_[176] = (GObject*) _tmp177_;
	_tmp199_[177] = (GObject*) _tmp178_;
	_tmp199_[178] = (GObject*) _tmp179_;
	_tmp199_[179] = (GObject*) _tmp180_;
	_tmp199_[180] = (GObject*) _tmp181_;
	_tmp199_[181] = (GObject*) _tmp182_;
	_tmp199_[182] = (GObject*) _tmp183_;
	_tmp199_[183] = (GObject*) _tmp184_;
	_tmp199_[184] = (GObject*) _tmp185_;
	_tmp199_[185] = (GObject*) _tmp186_;
	_tmp199_[186] = (GObject*) _tmp187_;
	_tmp199_[187] = (GObject*) _tmp188_;
	_tmp199_[188] = (GObject*) _tmp189_;
	_tmp199_[189] = (GObject*) _tmp190_;
	_tmp199_[190] = (GObject*) _tmp191_;
	_tmp199_[191] = (GObject*) _tmp192_;
	_tmp199_[192] = (GObject*) _tmp193_;
	_tmp199_[193] = (GObject*) _tmp194_;
	_tmp199_[194] = (GObject*) _tmp195_;
	_tmp199_[195] = (GObject*) _tmp196_;
	_tmp199_[196] = (GObject*) _tmp197_;
	_tmp199_[197] = (GObject*) _tmp198_;
	_tmp200_ = _tmp199_;
	_tmp200__length1 = 198;
	g_list_store_splice (_tmp0_, (guint) 0, (guint) 0, _tmp200_, (guint) 198);
	_tmp200_ = (_vala_array_free (_tmp200_, _tmp200__length1, (GDestroyNotify) g_object_unref), NULL);
	return obj;
}

static void
tuba_utils_locales_class_init (TubaUtilsLocalesClass * klass,
                               gpointer klass_data)
{
	tuba_utils_locales_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->constructor = tuba_utils_locales_constructor;
	G_OBJECT_CLASS (klass)->finalize = tuba_utils_locales_finalize;
}

static void
tuba_utils_locales_instance_init (TubaUtilsLocales * self,
                                  gpointer klass)
{
	GListStore* _tmp0_;
	_tmp0_ = g_list_store_new (TUBA_UTILS_LOCALES_TYPE_LOCALE);
	self->list_store = _tmp0_;
}

static void
tuba_utils_locales_finalize (GObject * obj)
{
	TubaUtilsLocales * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_UTILS_TYPE_LOCALES, TubaUtilsLocales);
	_g_object_unref0 (self->list_store);
	G_OBJECT_CLASS (tuba_utils_locales_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_utils_locales_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaUtilsLocalesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_utils_locales_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaUtilsLocales), 0, (GInstanceInitFunc) tuba_utils_locales_instance_init, NULL };
	GType tuba_utils_locales_type_id;
	tuba_utils_locales_type_id = g_type_register_static (G_TYPE_OBJECT, "TubaUtilsLocales", &g_define_type_info, G_TYPE_FLAG_NONE);
	return tuba_utils_locales_type_id;
}

GType
tuba_utils_locales_get_type (void)
{
	static GType tuba_utils_locales_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_utils_locales_type_id__once)) {
		GType tuba_utils_locales_type_id;
		tuba_utils_locales_type_id = tuba_utils_locales_get_type_once ();
		g_once_init_leave_pointer (&tuba_utils_locales_type_id__once, tuba_utils_locales_type_id);
	}
	return tuba_utils_locales_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

